pub struct CompressedEdwardsY(pub [u8; 57]);Expand description
Represents a point on the Compressed Twisted Edwards Curve in little endian format where the most significant bit is the sign bit and the remaining 448 bits represent the y-coordinate
Tuple Fields
0: [u8; 57]Implementations
Sourceimpl CompressedEdwardsY
impl CompressedEdwardsY
Sourcepub fn decompress_unchecked(&self) -> CtOption<AffinePoint>
pub fn decompress_unchecked(&self) -> CtOption<AffinePoint>
Attempt to decompress to an AffinePoint.
Returns None if the input is not the \(y\)-coordinate of a
curve point.
Sourcepub fn decompress(&self) -> CtOption<AffinePoint>
pub fn decompress(&self) -> CtOption<AffinePoint>
Attempt to decompress to an AffinePoint.
Returns None:
- if the input is not the \(y\)-coordinate of a curve point.
- if the input point is not on the curve.
- if the input point has nonzero torsion component.